use strict;
use warnings;
package Role;

use Role::Tiny;
use Scalar::Util 'reftype';
use namespace::clean;

sub role_stuff {}

1;
